```
Usage: vcd vapp create [OPTIONS] <name>

Options:
  -d, --description text         vApp description
  -c, --catalog name             Catalog where the template is
  -t, --template name            Name of the template
  -n, --network name             Network
  -i, --ip-allocation-mode mode  IP allocation mode
  -m, --memory <MB>              Amount of memory in MB
  -u, --cpu <virtual-cpus>       Number of CPUs
  -k, --disk-size <MB>           Size of the vm home disk in MB
  -v, --vm-name name             VM name
  -o, --hostname hostname        Hostname
  -s, --storage-profile name     Name of the storage profile for the vApp
  -a, --accept-all-eulas         Accept all EULAs
  -h, --help                     Show this message and exit.

```
